@@ -285,6 +285,7 @@ KSysGuardProcessList::KSysGuardProcessList(QWidget* parent, const QString &hostN
     d->mUi->treeView->header()->hideSection(ProcessModel::HeadingVmSize);
     d->mUi->treeView->header()->hideSection(ProcessModel::HeadingNiceness);
     d->mUi->treeView->header()->hideSection(ProcessModel::HeadingTty);
+    d->mUi->treeView->header()->hideSection(ProcessModel::HeadingStartTime);
     d->mUi->treeView->header()->hideSection(ProcessModel::HeadingCommand);
     d->mUi->treeView->header()->hideSection(ProcessModel::HeadingPid);
     d->mUi->treeView->header()->hideSection(ProcessModel::HeadingCPUTime);
@@ -447,7 +448,7 @@ void KSysGuardProcessList::showProcessContextMenu(const QPoint &point) {
 
 
     //If the selected process is a zombie, do not bother offering renice and kill options
-    bool showSignalingEntries = numProcesses != 1 || process->status != KSysGuard::Process::Zombie;
+    bool showSignalingEntries = numProcesses != 1 || process->status() != KSysGuard::Process::Zombie;
     if(showSignalingEntries) {
         d->mProcessContextMenu->addAction(d->renice);
         QMenu *signalMenu = d->mProcessContextMenu->addMenu(i18n("Send Signal"));
@@ -461,19 +462,19 @@ void KSysGuardProcessList::showProcessContextMenu(const QPoint &point) {
         signalMenu->addAction(d->sigUsr2);
     }
 
-    if(numProcesses == 1 && process->parent_pid > 1) {
+    if(numProcesses == 1 && process->parentPid() > 1) {
         //As a design decision, I do not show the 'Jump to parent process' option when the
         //parent is just 'init'.
 
-        KSysGuard::Process *parent_process = d->mModel.getProcess(process->parent_pid);
+        KSysGuard::Process *parent_process = d->mModel.getProcess(process->parentPid());
         if(parent_process) { //it should not be possible for this process to not exist, but check just incase
-            QString parent_name = parent_process->name;
+            QString parent_name = parent_process->name();
             d->selectParent->setText(i18n("Jump to Parent Process (%1)", parent_name));
             d->mProcessContextMenu->addAction(d->selectParent);
         }
     }
 
-    if(numProcesses == 1 && process->tracerpid >= 0) {
+    if(numProcesses == 1 && process->tracerpid() >= 0) {
         //If the process is being debugged, offer to select it
         d->mProcessContextMenu->addAction(d->selectTracer);
     }
@@ -482,7 +483,7 @@ void KSysGuardProcessList::showProcessContextMenu(const QPoint &point) {
         d->mProcessContextMenu->addAction(d->window);
     }
 
-    if(numProcesses == 1 && process->status == KSysGuard::Process::Stopped) {
+    if(numProcesses == 1 && process->status() == KSysGuard::Process::Stopped) {
         //If the process is stopped, offer to resume it
         d->mProcessContextMenu->addAction(d->resume);
     }
@@ -495,7 +496,7 @@ void KSysGuardProcessList::showProcessContextMenu(const QPoint &point) {
     if (showSignalingEntries) {
         d->mProcessContextMenu->addSeparator();
         d->mProcessContextMenu->addAction(d->terminate);
-        if (numProcesses == 1 && !process->timeKillWasSent.isNull())
+        if (numProcesses == 1 && !process->timeKillWasSent().isNull())
             d->mProcessContextMenu->addAction(d->kill);
     }
 
@@ -522,7 +523,7 @@ void KSysGuardProcessList::actionTriggered(QObject *object) {
         QModelIndex realIndex = d->mFilterModel.mapToSource(selectedIndexes.at(0));
         KSysGuard::Process *process = reinterpret_cast<KSysGuard::Process *> (realIndex.internalPointer());
         if(process)
-            selectAndJumpToProcess(process->parent_pid);
+            selectAndJumpToProcess(process->parentPid());
     } else if(result == d->selectTracer) {
         QModelIndexList selectedIndexes = d->mUi->treeView->selectionModel()->selectedRows();
         int numProcesses = selectedIndexes.size();
@@ -530,7 +531,7 @@ void KSysGuardProcessList::actionTriggered(QObject *object) {
         QModelIndex realIndex = d->mFilterModel.mapToSource(selectedIndexes.at(0));
         KSysGuard::Process *process = reinterpret_cast<KSysGuard::Process *> (realIndex.internalPointer());
         if(process)
-            selectAndJumpToProcess(process->tracerpid);
+            selectAndJumpToProcess(process->tracerpid());
     } else if(result == d->window) {
         QModelIndexList selectedIndexes = d->mUi->treeView->selectionModel()->selectedRows();
         int numProcesses = selectedIndexes.size();
@@ -1066,16 +1067,16 @@ void KSysGuardProcessList::reniceSelectedProcesses()
         int sched = -2;
         int iosched = -2;
         foreach(KSysGuard::Process *process, processes) {
-            pids << process->pid;
+            pids << process->pid();
             selectedAsStrings << d->mModel.getStringForProcess(process);
-            if(sched == -2) sched = (int)process->scheduler;
-            else if(sched != -1 && sched != (int)process->scheduler) sched = -1;  //If two processes have different schedulers, disable the cpu scheduler stuff
-            if(iosched == -2) iosched = (int)process->ioPriorityClass;
-            else if(iosched != -1 && iosched != (int)process->ioPriorityClass) iosched = -1;  //If two processes have different schedulers, disable the cpu scheduler stuff
+            if(sched == -2) sched = (int)process->scheduler();
+            else if(sched != -1 && sched != (int)process->scheduler()) sched = -1;  //If two processes have different schedulers, disable the cpu scheduler stuff
+            if(iosched == -2) iosched = (int)process->ioPriorityClass();
+            else if(iosched != -1 && iosched != (int)process->ioPriorityClass()) iosched = -1;  //If two processes have different schedulers, disable the cpu scheduler stuff
 
         }
-        int firstPriority = processes.first()->niceLevel;
-        int firstIOPriority = processes.first()->ioniceLevel;
+        int firstPriority = processes.first()->niceLevel();
+        int firstIOPriority = processes.first()->ioniceLevel();
 
         bool supportsIoNice = d->mModel.processController()->supportsIoNiceness();
         if(!supportsIoNice) { iosched = -2; firstIOPriority = -2; }
@@ -1103,16 +1104,16 @@ void KSysGuardProcessList::reniceSelectedProcesses()
                 break;  //So do nothing
             case KSysGuard::Process::Other:
             case KSysGuard::Process::Fifo:
-                if(reniceDlg->newCPUSched != (int)process->scheduler) {
+                if(reniceDlg->newCPUSched != (int)process->scheduler()) {
                     changeCPUSchedulerPids << pid;
                     renicePids << pid;
-                } else if(reniceDlg->newCPUPriority != process->niceLevel)
+                } else if(reniceDlg->newCPUPriority != process->niceLevel())
                     renicePids << pid;
                 break;
 
             case KSysGuard::Process::RoundRobin:
             case KSysGuard::Process::Batch:
-                if(reniceDlg->newCPUSched != (int)process->scheduler || reniceDlg->newCPUPriority != process->niceLevel) {
+                if(reniceDlg->newCPUSched != (int)process->scheduler() || reniceDlg->newCPUPriority != process->niceLevel()) {
                     changeCPUSchedulerPids << pid;
                 }
                 break;
@@ -1122,22 +1123,22 @@ void KSysGuardProcessList::reniceSelectedProcesses()
             case -1:  //Invalid, not changed etc.
                 break;  //So do nothing
             case KSysGuard::Process::None:
-                if(reniceDlg->newIOSched != (int)process->ioPriorityClass) {
+                if(reniceDlg->newIOSched != (int)process->ioPriorityClass()) {
                     // Unfortunately linux doesn't actually let us set the ioniceness back to none after being set to something else
-                    if(process->ioPriorityClass != KSysGuard::Process::BestEffort || reniceDlg->newIOPriority != process->ioniceLevel)
+                    if(process->ioPriorityClass() != KSysGuard::Process::BestEffort || reniceDlg->newIOPriority != process->ioniceLevel())
                         changeIOSchedulerPids << pid;
                 }
                 break;
             case KSysGuard::Process::Idle:
-                if(reniceDlg->newIOSched != (int)process->ioPriorityClass) {
+                if(reniceDlg->newIOSched != (int)process->ioPriorityClass()) {
                     changeIOSchedulerPids << pid;
                 }
                 break;
             case KSysGuard::Process::BestEffort:
-                if(process->ioPriorityClass == KSysGuard::Process::None && reniceDlg->newIOPriority  == (process->niceLevel + 20)/5)
+                if(process->ioPriorityClass() == KSysGuard::Process::None && reniceDlg->newIOPriority  == (process->niceLevel() + 20)/5)
                     break;  //Don't set to BestEffort if it's on None and the nicelevel wouldn't change
             case KSysGuard::Process::RealTime:
-                if(reniceDlg->newIOSched != (int)process->ioPriorityClass || reniceDlg->newIOPriority != process->ioniceLevel) {
+                if(reniceDlg->newIOSched != (int)process->ioPriorityClass() || reniceDlg->newIOPriority != process->ioniceLevel()) {
                     changeIOSchedulerPids << pid;
                 }
                 break;
@@ -1275,7 +1276,7 @@ void KSysGuardProcessList::sendSignalToSelectedProcesses(int sig, bool confirm)
 
     QList<KSysGuard::Process *> processes = selectedProcesses();
     foreach(KSysGuard::Process *process, processes) {
-        selectedPids << process->pid;
+        selectedPids << process->pid();
         if (!confirm)
             continue;
         QString name = d->mModel.getStringForProcess(process);
@@ -1326,7 +1327,7 @@ void KSysGuardProcessList::sendSignalToSelectedProcesses(int sig, bool confirm)
         foreach (long long pid, selectedPids) {
             KSysGuard::Process *process = d->mModel.getProcess(pid);
             if (process)
-                process->timeKillWasSent.start();
+                process->timeKillWasSent().start();
             d->mUi->treeView->selectionModel()->clearSelection();
         }
     }
